<?php
function _updateGroup(&$tof,$vars) {
	require_once("actions/groups.php");
	$group = array( 'GroupID' => $vars['GroupID'],
					'Name' => $vars['groupName'] );
	updateGroup($tof,$group,$vars['groupUsers']);
}
?>